@@ -73,6 +73,16 @@ cb_rgstrar_update_contact_list (psp_request_t * psp_req)
   OSIP_TRACE (osip_trace (__FILE__, __LINE__, OSIP_INFO2, NULL,
 			  "rgstrar plugin: Updating contact list of a user!\n"));
 
+  if (request->to==NULL
+      || request->to->url==NULL
+      || request->to->url->username==NULL)
+    {
+      psp_request_set_uas_status (psp_req, 403);
+      psp_request_set_mode (psp_req, PSP_UAS_MODE);
+      psp_request_set_state (psp_req, PSP_MANDATE);
+      return 0;
+    }
+
   user = ppl_uinfo_find_by_aor (request->to->url);
   if (user == NULL)
     user = ppl_uinfo_create (request->to->url, NULL, NULL);
