@@ -857,6 +857,23 @@ cb_snd_udp_message (osip_transaction_t * transaction,	/* read only element */
   /* For REQUEST,  oSIP SOMETIMES provide host and port to use which
      may be different from the request uri */
 
+  if (transaction==NULL && MSG_IS_REQUEST(message))
+    {
+      /* recalculate destination */
+      osip_route_t *route;
+      host = NULL;
+      port=5060;
+      osip_message_get_route (message, 0, &route);
+      if (route != NULL)
+	{
+	  int port = 5060;
+	  
+	  if (route->url->port != NULL)
+	    port = osip_atoi (route->url->port);
+	  host = route->url->host;
+	}
+    }
+
   if (host == NULL)
     {				/* when host is NULL, we use the request uri value */
       host = message->req_uri->host;
