@@ -470,8 +470,12 @@ osip_msg_default_build_request_osip_to_forward (osip_message_t ** dest,
 	}
     }
   /*        4.   Optionally add a Record-route header field value */
-  if (stayonpath && MSG_IS_INVITE (request))
-    {				/* AMD: 14/10/2002 This information is usefull only for INVITE */
+  if (stayonpath && (MSG_IS_INVITE (request)
+		     || MSG_IS_SUBSCRIBE (request)
+		     || MSG_IS_NOTIFY(request)))
+    {
+      /* AMD: 14/10/2002 This information is usefull only for INVITE 
+	 AMD: 20/04/2005 It's also necessary for SUBSCRIBE and NOTIFY */
       osip_record_route_t *r_route;
       char *tmp;
       osip_uri_t *url_of_proxy;
