@@ -1021,6 +1021,45 @@ psp_core_default_generate_branch_for_request (osip_message_t * request, char *br
 
 PPL_DECLARE (char *) psp_core_get_ip_of_local_proxy ()
 {
+  char def_gateway[50];
+  char *dyn_ip;
+
+  if (core->ipv6_enable != 1)
+    {
+      /* only implemented for IPv4 */
+
+      dyn_ip = psp_config_get_element ("dynamic_ip");
+      if (dyn_ip!=NULL && 0==osip_strcasecmp(dyn_ip, "on"))
+	{
+	  int i;
+	  memset(&def_gateway, '\0',sizeof(def_gateway));
+	  i = ppl_dns_default_gateway(AF_INET, def_gateway, 49);
+	  if (i!=0)
+	    {
+	      OSIP_TRACE (osip_trace (__FILE__, __LINE__, OSIP_INFO2, NULL,
+				      "Failed to re-detect default interface keep '%s'\n",
+				      core->serverip[0]));
+	    }
+	  else
+	    {
+	      char *tmp = core->serverip[0];
+	      core->serverip[0] = osip_malloc (50);
+	      if (core->serverip[0] == NULL)
+		core->serverip[0] = tmp; /* back to previous ip */
+	      else
+		{
+		  osip_free(tmp);
+		  osip_strncpy ((char *) core->serverip[0],
+				def_gateway,
+				strlen(def_gateway));
+		  OSIP_TRACE (osip_trace (__FILE__, __LINE__, OSIP_INFO2, NULL,
+					  "New default interface detected '%s'\n",
+					  core->serverip[0]));
+		}
+	    }
+	}
+    }
+
   if (core->ipv6_enable == 1)
     {
       struct in6_addr addr;
